@@ -1,5 +1,5 @@
 from threading import Lock
-from time import sleep, time
+from time import sleep, monotonic
 from math import ceil, inf
 from os import environ
 
@@ -94,15 +94,16 @@ class InertialTimeDerivate:
 
     Reads the counter, divides with time passed since last reading, and smooths the value using a moving average
     """
+
     def __init__(self, func, initial, inertia):
         self.func = func
         self.last_value = self.func()
-        self.last_check = time()
+        self.last_check = monotonic()
         self.inertial_value = MovingAverage(initial, inertia)
 
     def update(self):
         new_value = self.func()
-        this_check = time()
+        this_check = monotonic()
         elapsed = this_check - self.last_check
         delta = new_value - self.last_value
         self.last_check = this_check
@@ -170,7 +171,7 @@ def wait_for_idle_cpus(
         return cpu_used <= cpu_quota
 
     def wait_for_slot(halt):
-        start_time = time()
+        start_time = monotonic()
 
         idle = InertialTimeDerivate(lambda: cpu_times().idle, 0, inertia)
         cpu_used = InertialTimeDerivate(cpu_used_in_process, cpu_count(), inertia)
@@ -191,7 +192,7 @@ def wait_for_idle_cpus(
 
             sleep(cpu_poll_interval)
 
-        cpu_wait_time.update(time() - start_time)
+        cpu_wait_time.update(monotonic() - start_time)
 
         return worker_list.add_worker(Worker(required, keep_cpu_reservation))
 
